# gsnodegraph

Nodegraph widget for wxpython, created to be eventually used in [Gimel Studio](https://github.com/GimelStudio/GimelStudio).

**NOT YET READY FOR PRODUCTION!**

Highly inspired by Blender's nodes (with adjustments), if you couldn't tell. ;)


# Usage

Simply ```pip install gsnodegraph``` and run the ```main.py``` from a clone of [https://github.com/Correct-Syntax/gsnodegraph](https://github.com/Correct-Syntax/gsnodegraph) to see the WIP nodegraph.


# Status & Roadmap

This is currently (highly) WIP -as-in, some things work, but needs a lot more work. So, this is *not production-ready*, yet!

**Roadmap**

- [x] Zoom/pan canvas
- [x] Basic node drag n' drop
- [x] Box selection
- [x] Multi-selection
- [x] Sockets and wires
- [ ] Lock zoom to a predefined range
- [ ] Properties & Parameters
- [ ] Support image thumbnails
- [ ] Implement node delete, duplicate
- [ ] Configuration (toggle AA, grid, etc)
- [ ] Cleanup + Bug testing
- [x] Make PYPI package


**Extra possiblities**

- [ ] Nodegraph minimap?
- [ ] Image as background?


# Contributing

All contributions are welcome! Feel free to open a PR or ask questions.
